@@ -9,25 +9,20 @@
 var escapeRe = require('escape-string-regexp');
 var path = require('path');
 var builtinReporters = require('./reporters');
-var growl = require('./nodejs/growl');
 var utils = require('./utils');
 var mocharc = require('./mocharc.json');
 var Suite = require('./suite');
 var esmUtils = require('./nodejs/esm-utils');
 var createStatsCollector = require('./stats-collector');
 const {
-  warn,
   createInvalidReporterError,
   createInvalidInterfaceError,
   createMochaInstanceAlreadyDisposedError,
   createMochaInstanceAlreadyRunningError,
   createUnsupportedError
 } = require('./errors');
-const {
-  EVENT_FILE_PRE_REQUIRE,
-  EVENT_FILE_POST_REQUIRE,
-  EVENT_FILE_REQUIRE
-} = Suite.constants;
+const {EVENT_FILE_PRE_REQUIRE, EVENT_FILE_POST_REQUIRE, EVENT_FILE_REQUIRE} =
+  Suite.constants;
 var debug = require('debug')('mocha:mocha');
 
 exports = module.exports = Mocha;
@@ -94,46 +89,46 @@ exports.Hook = require('./hook');
 exports.Test = require('./test');
 
 let currentContext;
-exports.afterEach = function(...args) {
+exports.afterEach = function (...args) {
   return (currentContext.afterEach || currentContext.teardown).apply(
     this,
     args
   );
 };
-exports.after = function(...args) {
+exports.after = function (...args) {
   return (currentContext.after || currentContext.suiteTeardown).apply(
     this,
     args
   );
 };
-exports.beforeEach = function(...args) {
+exports.beforeEach = function (...args) {
   return (currentContext.beforeEach || currentContext.setup).apply(this, args);
 };
-exports.before = function(...args) {
+exports.before = function (...args) {
   return (currentContext.before || currentContext.suiteSetup).apply(this, args);
 };
-exports.describe = function(...args) {
+exports.describe = function (...args) {
   return (currentContext.describe || currentContext.suite).apply(this, args);
 };
-exports.describe.only = function(...args) {
+exports.describe.only = function (...args) {
   return (currentContext.describe || currentContext.suite).only.apply(
     this,
     args
   );
 };
-exports.describe.skip = function(...args) {
+exports.describe.skip = function (...args) {
   return (currentContext.describe || currentContext.suite).skip.apply(
     this,
     args
   );
 };
-exports.it = function(...args) {
+exports.it = function (...args) {
   return (currentContext.it || currentContext.test).apply(this, args);
 };
-exports.it.only = function(...args) {
+exports.it.only = function (...args) {
   return (currentContext.it || currentContext.test).only.apply(this, args);
 };
-exports.it.skip = function(...args) {
+exports.it.skip = function (...args) {
   return (currentContext.it || currentContext.test).skip.apply(this, args);
 };
 exports.xdescribe = exports.describe.skip;
@@ -144,7 +139,7 @@ exports.suiteTeardown = exports.after;
 exports.suite = exports.describe;
 exports.teardown = exports.afterEach;
 exports.test = exports.it;
-exports.run = function(...args) {
+exports.run = function (...args) {
   return currentContext.run.apply(this, args);
 };
 
@@ -169,7 +164,6 @@ exports.run = function(...args) {
  * @param {boolean} [options.fullTrace] - Full stacktrace upon failure?
  * @param {string[]} [options.global] - Variables expected in global scope.
  * @param {RegExp|string} [options.grep] - Test filter given regular expression.
- * @param {boolean} [options.growl] - Enable desktop notifications?
  * @param {boolean} [options.inlineDiffs] - Display inline diffs?
  * @param {boolean} [options.invert] - Invert test filter matches?
  * @param {boolean} [options.noHighlighting] - Disable syntax highlighting?
@@ -199,7 +193,7 @@ function Mocha(options = {}) {
     .ui(options.ui)
     .reporter(
       options.reporter,
-      options.reporterOption || options.reporterOptions // for backwards compability
+      options.reporterOption || options.reporterOptions // for backwards compatibility
     )
     .slow(options.slow)
     .global(options.global);
@@ -226,10 +220,9 @@ function Mocha(options = {}) {
     'forbidOnly',
     'forbidPending',
     'fullTrace',
-    'growl',
     'inlineDiffs',
     'invert'
-  ].forEach(function(opt) {
+  ].forEach(function (opt) {
     if (options[opt]) {
       this[opt]();
     }
@@ -287,7 +280,7 @@ function Mocha(options = {}) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.bail = function(bail) {
+Mocha.prototype.bail = function (bail) {
   this.suite.bail(bail !== false);
   return this;
 };
@@ -305,7 +298,7 @@ Mocha.prototype.bail = function(bail) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.addFile = function(file) {
+Mocha.prototype.addFile = function (file) {
   this.files.push(file);
   return this;
 };
@@ -326,7 +319,7 @@ Mocha.prototype.addFile = function(file) {
  * // Use XUnit reporter and direct its output to file
  * mocha.reporter('xunit', { output: '/path/to/testspec.xunit.xml' });
  */
-Mocha.prototype.reporter = function(reporterName, reporterOptions) {
+Mocha.prototype.reporter = function (reporterName, reporterOptions) {
   if (typeof reporterName === 'function') {
     this._reporter = reporterName;
   } else {
@@ -338,35 +331,26 @@ Mocha.prototype.reporter = function(reporterName, reporterOptions) {
     }
     // Try to load reporters from process.cwd() and node_modules
     if (!reporter) {
+      let foundReporter;
       try {
-        reporter = require(reporterName);
+        foundReporter = require.resolve(reporterName);
+        reporter = require(foundReporter);
       } catch (err) {
-        if (err.code === 'MODULE_NOT_FOUND') {
-          // Try to load reporters from a path (absolute or relative)
-          try {
-            reporter = require(path.resolve(utils.cwd(), reporterName));
-          } catch (_err) {
-            _err.code === 'MODULE_NOT_FOUND'
-              ? warn(`'${reporterName}' reporter not found`)
-              : warn(
-                  `'${reporterName}' reporter blew up with error:\n ${err.stack}`
-                );
-          }
-        } else {
-          warn(`'${reporterName}' reporter blew up with error:\n ${err.stack}`);
+        if (foundReporter) {
+          throw createInvalidReporterError(err.message, foundReporter);
+        }
+        // Try to load reporters from a cwd-relative path
+        try {
+          reporter = require(path.resolve(reporterName));
+        } catch (e) {
+          throw createInvalidReporterError(e.message, reporterName);
         }
       }
     }
-    if (!reporter) {
-      throw createInvalidReporterError(
-        `invalid reporter '${reporterName}'`,
-        reporterName
-      );
-    }
     this._reporter = reporter;
   }
   this.options.reporterOption = reporterOptions;
-  // alias option name is used in public reporters xunit/tap/progress
+  // alias option name is used in built-in reporters xunit/tap/progress
   this.options.reporterOptions = reporterOptions;
   return this;
 };
@@ -382,7 +366,7 @@ Mocha.prototype.reporter = function(reporterName, reporterOptions) {
  * @chainable
  * @throws {Error} if requested interface cannot be loaded
  */
-Mocha.prototype.ui = function(ui) {
+Mocha.prototype.ui = function (ui) {
   var bindInterface;
   if (typeof ui === 'function') {
     bindInterface = ui;
@@ -399,7 +383,7 @@ Mocha.prototype.ui = function(ui) {
   }
   bindInterface(this.suite);
 
-  this.suite.on(EVENT_FILE_PRE_REQUIRE, function(context) {
+  this.suite.on(EVENT_FILE_PRE_REQUIRE, function (context) {
     currentContext = context;
   });
 
@@ -421,10 +405,10 @@ Mocha.prototype.ui = function(ui) {
  * @see {@link Mocha#loadFilesAsync}
  * @param {Function} [fn] - Callback invoked upon completion.
  */
-Mocha.prototype.loadFiles = function(fn) {
+Mocha.prototype.loadFiles = function (fn) {
   var self = this;
   var suite = this.suite;
-  this.files.forEach(function(file) {
+  this.files.forEach(function (file) {
     file = path.resolve(file);
     suite.emit(EVENT_FILE_PRE_REQUIRE, global, file, self);
     suite.emit(EVENT_FILE_REQUIRE, require(file), file, self);
@@ -453,17 +437,17 @@ Mocha.prototype.loadFiles = function(fn) {
  *   .then(() => mocha.run(failures => process.exitCode = failures ? 1 : 0))
  *   .catch(() => process.exitCode = 1);
  */
-Mocha.prototype.loadFilesAsync = function() {
+Mocha.prototype.loadFilesAsync = function () {
   var self = this;
   var suite = this.suite;
   this.lazyLoadFiles(true);
 
   return esmUtils.loadFilesAsync(
     this.files,
-    function(file) {
+    function (file) {
       suite.emit(EVENT_FILE_PRE_REQUIRE, global, file, self);
     },
-    function(file, resultModule) {
+    function (file, resultModule) {
       suite.emit(EVENT_FILE_REQUIRE, resultModule, file, self);
       suite.emit(EVENT_FILE_POST_REQUIRE, global, file, self);
     }
@@ -478,10 +462,10 @@ Mocha.prototype.loadFilesAsync = function() {
  * @see {@link Mocha#unloadFiles}
  * @param {string} file - Pathname of file to be unloaded.
  */
-Mocha.unloadFile = function(file) {
+Mocha.unloadFile = function (file) {
   if (utils.isBrowser()) {
     throw createUnsupportedError(
-      'unloadFile() is only suported in a Node.js environment'
+      'unloadFile() is only supported in a Node.js environment'
     );
   }
   return require('./nodejs/file-unloader').unloadFile(file);
@@ -502,7 +486,7 @@ Mocha.unloadFile = function(file) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.unloadFiles = function() {
+Mocha.prototype.unloadFiles = function () {
   if (this._state === mochaStates.DISPOSED) {
     throw createMochaInstanceAlreadyDisposedError(
       'Mocha instance is already disposed, it cannot be used again.',
@@ -511,7 +495,7 @@ Mocha.prototype.unloadFiles = function() {
     );
   }
 
-  this.files.forEach(function(file) {
+  this.files.forEach(function (file) {
     Mocha.unloadFile(file);
   });
   this._state = mochaStates.INIT;
@@ -531,7 +515,7 @@ Mocha.prototype.unloadFiles = function() {
  * // Select tests whose full title begins with `"foo"` followed by a period
  * mocha.fgrep('foo.');
  */
-Mocha.prototype.fgrep = function(str) {
+Mocha.prototype.fgrep = function (str) {
   if (!str) {
     return this;
   }
@@ -572,7 +556,7 @@ Mocha.prototype.fgrep = function(str) {
  * // Given embedded test `it('only-this-test')`...
  * mocha.grep('/^only-this-test$/');    // NO! Use `.only()` to do this!
  */
-Mocha.prototype.grep = function(re) {
+Mocha.prototype.grep = function (re) {
   if (utils.isString(re)) {
     // extract args if it's regex-like, i.e: [string, pattern, flag]
     var arg = re.match(/^\/(.*)\/([gimy]{0,4})$|.*/);
@@ -595,7 +579,7 @@ Mocha.prototype.grep = function(re) {
  * // Select tests whose full title does *not* contain `"match"`, ignoring case
  * mocha.grep(/match/i).invert();
  */
-Mocha.prototype.invert = function() {
+Mocha.prototype.invert = function () {
   this.options.invert = true;
   return this;
 };
@@ -609,7 +593,7 @@ Mocha.prototype.invert = function() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.checkLeaks = function(checkLeaks) {
+Mocha.prototype.checkLeaks = function (checkLeaks) {
   this.options.checkLeaks = checkLeaks !== false;
   return this;
 };
@@ -624,7 +608,7 @@ Mocha.prototype.checkLeaks = function(checkLeaks) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.cleanReferencesAfterRun = function(cleanReferencesAfterRun) {
+Mocha.prototype.cleanReferencesAfterRun = function (cleanReferencesAfterRun) {
   this._cleanReferencesAfterRun = cleanReferencesAfterRun !== false;
   return this;
 };
@@ -634,7 +618,7 @@ Mocha.prototype.cleanReferencesAfterRun = function(cleanReferencesAfterRun) {
  * It also removes function references to tests functions and hooks, so variables trapped in closures can be cleaned by the garbage collector.
  * @public
  */
-Mocha.prototype.dispose = function() {
+Mocha.prototype.dispose = function () {
   if (this._state === mochaStates.RUNNING) {
     throw createMochaInstanceAlreadyRunningError(
       'Cannot dispose while the mocha instance is still running tests.'
@@ -655,54 +639,11 @@ Mocha.prototype.dispose = function() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.fullTrace = function(fullTrace) {
+Mocha.prototype.fullTrace = function (fullTrace) {
   this.options.fullTrace = fullTrace !== false;
   return this;
 };
 
-/**
- * Enables desktop notification support if prerequisite software installed.
- *
- * @public
- * @see [CLI option](../#-growl-g)
- * @return {Mocha} this
- * @chainable
- */
-Mocha.prototype.growl = function() {
-  this.options.growl = this.isGrowlCapable();
-  if (!this.options.growl) {
-    var detail = utils.isBrowser()
-      ? 'notification support not available in this browser...'
-      : 'notification support prerequisites not installed...';
-    console.error(detail + ' cannot enable!');
-  }
-  return this;
-};
-
-/**
- * @summary
- * Determines if Growl support seems likely.
- *
- * @description
- * <strong>Not available when run in browser.</strong>
- *
- * @private
- * @see {@link Growl#isCapable}
- * @see {@link Mocha#growl}
- * @return {boolean} whether Growl support can be expected
- */
-Mocha.prototype.isGrowlCapable = growl.isCapable;
-
-/**
- * Implements desktop notifications using a pseudo-reporter.
- *
- * @private
- * @see {@link Mocha#growl}
- * @see {@link Growl#notify}
- * @param {Runner} runner - Runner instance.
- */
-Mocha.prototype._growl = growl.notify;
-
 /**
  * Specifies whitelist of variable names to be expected in global scope.
  *
@@ -717,16 +658,16 @@ Mocha.prototype._growl = growl.notify;
  * // Specify variables to be expected in global scope
  * mocha.global(['jQuery', 'MyLib']);
  */
-Mocha.prototype.global = function(global) {
+Mocha.prototype.global = function (global) {
   this.options.global = (this.options.global || [])
     .concat(global)
     .filter(Boolean)
-    .filter(function(elt, idx, arr) {
+    .filter(function (elt, idx, arr) {
       return arr.indexOf(elt) === idx;
     });
   return this;
 };
-// for backwards compability, 'globals' is an alias of 'global'
+// for backwards compatibility, 'globals' is an alias of 'global'
 Mocha.prototype.globals = Mocha.prototype.global;
 
 /**
@@ -738,7 +679,7 @@ Mocha.prototype.globals = Mocha.prototype.global;
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.color = function(color) {
+Mocha.prototype.color = function (color) {
   this.options.color = color !== false;
   return this;
 };
@@ -753,7 +694,7 @@ Mocha.prototype.color = function(color) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.inlineDiffs = function(inlineDiffs) {
+Mocha.prototype.inlineDiffs = function (inlineDiffs) {
   this.options.inlineDiffs = inlineDiffs !== false;
   return this;
 };
@@ -767,7 +708,7 @@ Mocha.prototype.inlineDiffs = function(inlineDiffs) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.diff = function(diff) {
+Mocha.prototype.diff = function (diff) {
   this.options.diff = diff !== false;
   return this;
 };
@@ -795,7 +736,7 @@ Mocha.prototype.diff = function(diff) {
  * // Same as above but using string argument
  * mocha.timeout('1s');
  */
-Mocha.prototype.timeout = function(msecs) {
+Mocha.prototype.timeout = function (msecs) {
   this.suite.timeout(msecs);
   return this;
 };
@@ -814,7 +755,7 @@ Mocha.prototype.timeout = function(msecs) {
  * // Allow any failed test to retry one more time
  * mocha.retries(1);
  */
-Mocha.prototype.retries = function(retry) {
+Mocha.prototype.retries = function (retry) {
   this.suite.retries(retry);
   return this;
 };
@@ -836,7 +777,7 @@ Mocha.prototype.retries = function(retry) {
  * // Same as above but using string argument
  * mocha.slow('0.5s');
  */
-Mocha.prototype.slow = function(msecs) {
+Mocha.prototype.slow = function (msecs) {
   this.suite.slow(msecs);
   return this;
 };
@@ -850,7 +791,7 @@ Mocha.prototype.slow = function(msecs) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.asyncOnly = function(asyncOnly) {
+Mocha.prototype.asyncOnly = function (asyncOnly) {
   this.options.asyncOnly = asyncOnly !== false;
   return this;
 };
@@ -862,7 +803,7 @@ Mocha.prototype.asyncOnly = function(asyncOnly) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.noHighlighting = function() {
+Mocha.prototype.noHighlighting = function () {
   this.options.noHighlighting = true;
   return this;
 };
@@ -876,7 +817,7 @@ Mocha.prototype.noHighlighting = function() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.allowUncaught = function(allowUncaught) {
+Mocha.prototype.allowUncaught = function (allowUncaught) {
   this.options.allowUncaught = allowUncaught !== false;
   return this;
 };
@@ -907,7 +848,7 @@ Mocha.prototype.delay = function delay() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.dryRun = function(dryRun) {
+Mocha.prototype.dryRun = function (dryRun) {
   this.options.dryRun = dryRun !== false;
   return this;
 };
@@ -921,7 +862,7 @@ Mocha.prototype.dryRun = function(dryRun) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.failZero = function(failZero) {
+Mocha.prototype.failZero = function (failZero) {
   this.options.failZero = failZero !== false;
   return this;
 };
@@ -935,7 +876,7 @@ Mocha.prototype.failZero = function(failZero) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.forbidOnly = function(forbidOnly) {
+Mocha.prototype.forbidOnly = function (forbidOnly) {
   this.options.forbidOnly = forbidOnly !== false;
   return this;
 };
@@ -949,7 +890,7 @@ Mocha.prototype.forbidOnly = function(forbidOnly) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.forbidPending = function(forbidPending) {
+Mocha.prototype.forbidPending = function (forbidPending) {
   this.options.forbidPending = forbidPending !== false;
   return this;
 };
@@ -958,7 +899,7 @@ Mocha.prototype.forbidPending = function(forbidPending) {
  * Throws an error if mocha is in the wrong state to be able to transition to a "running" state.
  * @private
  */
-Mocha.prototype._guardRunningStateTransition = function() {
+Mocha.prototype._guardRunningStateTransition = function () {
   if (this._state === mochaStates.RUNNING) {
     throw createMochaInstanceAlreadyRunningError(
       'Mocha instance is currently running tests, cannot start a next test run until this one is done',
@@ -1017,7 +958,7 @@ Object.defineProperty(Mocha.prototype, 'version', {
  * // exit with non-zero status if there were test failures
  * mocha.run(failures => process.exitCode = failures ? 1 : 0);
  */
-Mocha.prototype.run = function(fn) {
+Mocha.prototype.run = function (fn) {
   this._guardRunningStateTransition();
   this._state = mochaStates.RUNNING;
   if (this._previousRunner) {
@@ -1050,9 +991,6 @@ Mocha.prototype.run = function(fn) {
   if (options.global) {
     runner.globals(options.global);
   }
-  if (options.growl) {
-    this._growl(runner);
-  }
   if (options.color !== undefined) {
     exports.reporters.Base.useColors = options.color;
   }
@@ -1320,9 +1258,10 @@ Mocha.prototype.hasGlobalSetupFixtures = function hasGlobalSetupFixtures() {
  * @public
  * @returns {boolean}
  */
-Mocha.prototype.hasGlobalTeardownFixtures = function hasGlobalTeardownFixtures() {
-  return Boolean(this.options.globalTeardown.length);
-};
+Mocha.prototype.hasGlobalTeardownFixtures =
+  function hasGlobalTeardownFixtures() {
+    return Boolean(this.options.globalTeardown.length);
+  };
 
 /**
  * An alternative way to define root hooks that works with parallel runs.
